﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using C1.Chart.Test;
using C1.Win.C1Chart;

namespace ChartBenchmark.Controls
{
    class C1ChartCtrl : IChart
    {
        C1Chart _chart = new C1Chart();
        PlotType _ptype = PlotType.Column;

        public C1ChartCtrl()
        {
            _chart = CreateChart();
            _chart.ChartArea.Margins.SetMargins(0, 0, 0, 0);
            _chart.UseAntiAliasedGraphics = false;
            _chart.UseAntiAliasedText = false;
        }

        public PlotType PlotType
        {
            get
            {
                return _ptype;
            }

            set
            {
                _ptype = value;
            }
        }

        virtual protected C1Chart CreateChart()
        {
            return new C1Chart();
        }

        void SetPlotType()
        {
            var cgr = _chart.ChartGroups[0];
            var ser = cgr.ChartData.SeriesList[0];
            switch (this.PlotType)
            {
                case PlotType.Column:
                    cgr.ChartType = Chart2DTypeEnum.Bar;
                    break;
                case PlotType.Line:
                    cgr.ChartType = Chart2DTypeEnum.XYPlot;
                    ser.SymbolStyle.Shape = SymbolShapeEnum.None;
                    ser.LineStyle.Thickness = 1;
                    break;
                case PlotType.LineSymbols:
                    cgr.ChartType = Chart2DTypeEnum.XYPlot;
                    ser.SymbolStyle.Shape = SymbolShapeEnum.Box;
                    ser.LineStyle.Thickness = 1;
                    break;
                case PlotType.Scatter:
                    cgr.ChartType = Chart2DTypeEnum.XYPlot;
                    ser.LineStyle.Thickness = 0;
                    break;
                case PlotType.Area:
                    cgr.ChartType = Chart2DTypeEnum.Area;
                    break;
            }
        }

        public void Clear()
        {
            _chart.ChartGroups[0].ChartData.SeriesList.Clear();
            _chart.DataSource = null;
        }

        public void Create(ICollection<DataPoint> pts)
        {
            _chart.BeginUpdate();
            var ser = _chart.ChartGroups[0].ChartData.SeriesList.AddNewSeries();
            _chart.DataSource = pts;
            ser.X.DataField = "X";
            ser.Y.DataField = "Y";
            SetPlotType();
            _chart.EndUpdate();
            _chart.Refresh();
        }

        public void Create(double[] xs, double[] ys)
        {
            throw new NotImplementedException();
        }

        public string GetInfo()
        {
            return string.Format("{0} {1}", GetName(), _chart.GetType().Assembly.GetName().Version);
        }

        public virtual string GetName()
        {
            return "C1Chart";
        }

        public object GetControl()
        {
            return _chart;
        }
    }
}
